@@ -23,11 +23,11 @@ Strawberry Perl includes:
 
 =item *
 
-Perl 5.8.8 or Perl 5.10.0
+Perl 5.8.9 or Perl 5.10.0
 
 =item *
 
-Mingw GCC C/C++ compiler
+MingW GCC C/C++ compiler
 
 =item *
 
@@ -35,7 +35,7 @@ Dmake "make" tool
 
 =item *
 
-Every bundled and dual-life modules upgraded to the latest version.
+Every bundled and dual-life module upgraded to the latest version.
 
 =item *
 
@@ -58,7 +58,7 @@ Prebuilt and known-good C libraries for math, crypto and XML support.
 
 =item *
 
-B<BETA> - Additions that provide L<Portable> support.
+Additions that provide L<Portable> support.
 
 =back
 
@@ -70,13 +70,13 @@ Please note that B<Perl::Dist::Strawberry> B<does not> include the
 resulting Strawberry Perl installer. See the Strawberry Perl website at
 L<http://strawberryperl.com/> to download the Strawberry Perl installer.
 
-See L<Perl::Dist::Inno> for details on how the underlying distribution
+See L<Perl::Dist::WiX> for details on how the underlying distribution
 construction toolkit works.
 
 =head1 CHANGES FROM CORE PERL
 
 Strawberry Perl is and will continue to be based on the latest "stable"
-releases of Perl, currently 5.8.8 and 5.10.0.
+releases of Perl, currently 5.8.9, and 5.10.0.
 
 Some additional modifications are included that improve general
 compatibility with the Win32 platform or improve "turnkey" operation on
@@ -112,7 +112,7 @@ add the environment entries manually.
 
 =head1 METHODS
 
-In addition to extending various underlying L<Perl::Dist::Inno> methods,
+In addition to extending various underlying L<Perl::Dist::WiX> methods,
 Strawberry Perl adds some additional methods that provide installation
 support for miscellaneous tools that have not yet been promoted to the
 core.
@@ -121,18 +121,19 @@ core.
 
 use 5.006;
 use strict;
-use URI::file                   ();
-use Perl::Dist                  ();
-use Perl::Dist::Machine         ();
-use Perl::Dist::Util::Toolchain ();
+use base                        qw( Perl::Dist::WiX );
+use File::Spec::Functions       qw( catfile catdir  );
+use URI::file                   qw();
+use Perl::Dist::Machine         qw();
+use Perl::Dist::Util::Toolchain qw();
+use File::ShareDir              qw();
 
-use vars qw{$VERSION @ISA};
+use vars qw($VERSION);
 BEGIN {
-	$VERSION = '1.11';
-	@ISA     = 'Perl::Dist';
+	$VERSION = '2.00';
 }
 
-use Object::Tiny 1.06 qw{
+use Object::Tiny qw{
 	bin_patch
 };
 
@@ -153,8 +154,9 @@ The C<default_machine> class method is used to setup the most common
 machine for building Strawberry Perl.
 
 The machine provided creates a standard 5.8.8 distribution (.zip and .exe),
-a standard 5.10.0 distribution (.zip and .exe) and a Portable-enabled
-5.10.0 distribution (.zip only).
+a standard 5.8.9 distribution (.zip and .exe), a standard 5.10.0 
+distribution (.zip and .exe) and a Portable-enabled 5.10.0 distribution 
+(.zip only).
 
 Returns a L<Perl::Dist::Machine> object.
 
@@ -173,6 +175,7 @@ sub default_machine {
 	$machine->add_dimension('version');
 	$machine->add_option('version',
 		perl_version => '589',
+	    build_number => 2,
 	);
 	$machine->add_option('version',
 		perl_version => '5100',
@@ -189,6 +192,7 @@ sub default_machine {
 	);
 	$machine->add_option('drive',
 		image_dir => 'D:\strawberry',
+		msi       => 1,
 		zip       => 0,
 	);
 
@@ -204,74 +208,115 @@ sub default_machine {
 
 # Apply default paths
 sub new {
-	shift->SUPER::new(
-		app_id            => 'strawberryperl',
-		app_name          => 'Strawberry Perl',
-		app_publisher     => 'Vanilla Perl Project',
-		app_publisher_url => 'http://vanillaperl.org/',
-		image_dir         => 'C:\\strawberry',
+	my $dist_dir = File::ShareDir::dist_dir('Perl-Dist-Strawberry');
 
-		# Build both exe and zip versions
-		exe               => 1,
-		zip               => 1,
+	# This is so msi_directory_tree_additions is additive, and doesn't
+	# get replaced by the subclass' parameter of that name.
+	my $self = shift;
+	my $params = {@_};
+	my $additions = $params->{msi_directory_tree_additions} || [];
+	$params->{perl_version} ||= '5100';
+	my @additions = @{$additions};
+	unshift @additions, qw(
+		perl\lib\ExtUtils\CBuilder
+		perl\lib\ExtUtils\CBuilder\Platform
+		perl\lib\IO\Compress\Adapter
+		perl\lib\IO\Compress\Base
+		perl\lib\IO\Compress\Gzip
+		perl\lib\IO\Compress\Zip
+		perl\lib\IO\Uncompress\Adapter
+		perl\lib\Math\BigInt\FastCalc
+		perl\lib\auto\Cwd
+		perl\site\lib\Bundle
+		perl\site\lib\Bundle\DBD
+		perl\site\lib\CPAN
+		perl\site\lib\DBD
+		perl\site\lib\IPC
+		perl\site\lib\JSON
+		perl\site\lib\LWP
+		perl\site\lib\Math
+		perl\site\lib\PAR
+		perl\site\lib\PAR\Dist
+		perl\site\lib\PAR\Repository
+		perl\site\lib\Parse
+		perl\site\lib\Pod
+		perl\site\lib\Test
+		perl\site\lib\XML
+		perl\site\lib\XML\LibXML
+		perl\site\lib\auto\CPAN
+		perl\site\lib\auto\DBD
+		perl\site\lib\auto\DBD\mysql
+		perl\site\lib\auto\IPC
+		perl\site\lib\auto\JSON
+		perl\site\lib\auto\LWP
+		perl\site\lib\auto\Math
+		perl\site\lib\auto\PAR
+		perl\site\lib\auto\PAR\Dist
+		perl\site\lib\auto\PAR\Repository
+		perl\site\lib\auto\Parse
+		perl\site\lib\auto\Pod
+		perl\site\lib\auto\Test
+		perl\site\lib\auto\Win32\File
+		perl\site\lib\auto\XML
+		perl\site\lib\auto\XML\LibXML
+	);
+	if (substr ($params->{perl_version}, 0, 2) eq '58') {
+		unshift @additions, qw(
+			perl\site\lib\Module
+		);
+	}
+	@additions = sort @additions;
+	$params->{msi_directory_tree_additions} = \@additions;
 
-		@_,
+	$self->SUPER::new(
+		app_id               => 'strawberryperl',
+		app_name             => 'Strawberry Perl',
+		app_publisher        => 'Vanilla Perl Project',
+		app_publisher_url    => 'http://www.strawberryperl.com/',
+		image_dir            => 'C:\strawberry',
+
+		# Program version.
+		build_number         => 6,
+
+		# New options for msi building...
+		msi_license_file     => catfile($dist_dir, 'License-short.rtf'),
+		msi_product_icon     => catfile(File::ShareDir::dist_dir('Perl-Dist-WiX'), 'win32.ico'),
+		msi_help_url         => 'http://www.strawberryperl.com/support.html',
+		msi_banner_top       => catfile($dist_dir, 'StrawberryBanner.bmp'),
+		msi_banner_side      => catfile($dist_dir, 'StrawberryDialog.bmp'),
+
+		# Set e-mail to something Strawberry-specific.
+		perl_config_cf_email => 'win32-vanilla@perl.org',
+
+		# Build both msi and zip versions
+		msi                  => 1,
+		zip                  => 1,
+
+		%{$params},
 	);
 }
 
 # Lazily default the full name.
 # Supports building multiple versions of Perl.
 sub app_ver_name {
-	my $self = shift;
-	if ( $self->{app_ver_name} ) {
-		return $self->{app_ver_name};
-	}
-
-	my $version = $self->perl_version_human;
-	my $name    = $self->app_name;
-
-	if ( $self->portable ) {
-		$name .= ' Portable';
-	}
-
-	# Add the version
-	$name .= " $version";
-	if ( $version eq '5.8.9' ) {
-		$name .= '.1';
-	} else {
-		$name .= '.5';
-	}
-
-	return $name;
+	$_[0]->{app_ver_name} or
+	$_[0]->app_name
+		. ($_[0]->portable ? ' Portable' : '')
+		. ' ' . $_[0]->perl_version_human
+		. '.' . $_[0]->build_number
+		. ($_[0]->beta_number ? ' Beta ' . $_[0]->beta_number : '');
 }
 
 # Lazily default the file name.
 # Supports building multiple versions of Perl.
 sub output_base_filename {
-	my $self = shift;
-	if ( $self->{output_base_filename} ) {
-		return $self->{output_base_filename};
-	}
-
-	my $version = $self->perl_version_human;
-	my $file    = "strawberry-perl-$version";
-
-	# Add the version
-	if ( $version eq '5.8.9' ) {
-		$file .= '.1';
-	} else {
-		$file .= '.5';
-	}
-
-	if ( $self->image_dir =~ /^d:/i ) {
-		$file .= '-ddrive';
-	}
-
-	if ( $self->portable ) {
-		$file .= '-portable';
-	}
-
-	return $file;
+	$_[0]->{output_base_filename} or
+	'strawberry-perl'
+		. '-' . $_[0]->perl_version_human
+		. '.' . $_[0]->build_number
+		. ($_[0]->image_dir =~ /^d:/i ? '-ddrive' : '')
+		. ($_[0]->portable ? '-portable' : '')
+		. ($_[0]->beta_number ? '-beta-' . $_[0]->beta_number : '')
 }
 
 
@@ -364,18 +409,6 @@ sub install_perl_588_bin {
 	);
 }
 
-sub install_perl_589_bin {
-	my $self   = shift;
-	my %params = @_;
-	my $patch  = delete($params{patch}) || [];
-	return $self->SUPER::install_perl_589_bin(
-		patch => [ qw{
-			win32/config.gc
-		}, @$patch ],
-		%params,
-	);
-}
-
 sub install_perl_5100_bin {
 	my $self   = shift;
 	my %params = @_;
@@ -391,6 +424,8 @@ sub install_perl_5100_bin {
 sub install_perl_modules {
 	my $self = shift;
 
+	$self->install_cpan_upgrades;
+	
 	# Install LWP::Online so our custom minicpan code works
 	$self->install_distribution(
 		name => 'ADAMK/LWP-Online-1.07.tar.gz'
@@ -399,17 +434,16 @@ sub install_perl_modules {
 	# Win32 Modules
 	$self->install_modules( qw{
 		Win32::File
+		File::Remove
 		Win32::File::Object
 		Win32::API
+		Parse::Binary
 		Win32::Exe
 	} );
 
 	# Install additional math modules
 	$self->install_pari;
 	$self->install_modules( qw{
-		Math::BigInt
-		Math::BigInt::FastCalc
-		Math::BigRat
 		Math::BigInt::GMP
 	} );
 
@@ -421,40 +455,67 @@ sub install_perl_modules {
 			'EXPATINCPATH=' . $self->dir(qw{ c include }),
 		],
 	);
+
+	$self->install_modules( qw{
+		XML::NamespaceSupport
+		XML::SAX
+		XML::LibXML::Common
+	} );
+
 	$self->install_module(
 		name => 'XML::LibXML',
 	);
 
 	# Networking Enhancements
-	$self->install_modules( qw{
-		Bundle::LWP
-	} );
+	# All the Bundle::LWP modules are
+	# included in the toolchain or in the upgrades.
 
 	# Binary Package Support
 	$self->install_modules( qw{
+		PAR::Dist
+		PAR::Dist::FromPPD
 		PAR::Dist::InstallPPD
+		Sub::Uplevel
 		Test::Exception
-		IO::Scalar
+		Array::Compare
+		Tree::DAG_Node
 		Test::Warn
+		Test::Tester
+		Test::NoWarnings
 		Test::Deep
+		IO::Scalar
 	} );
 	$self->install_distribution(
 		name  => 'RKINYON/DBM-Deep-1.0013.tar.gz',
 		force => 1,
 	);
-	$self->install_module(
-		name  => 'PAR',
-		# In the cleaup test script, the test doesn't
-		# handle Win32's non-instant delete problem.
-		force => 1,
-	);
 	$self->install_modules( qw{
+		YAML::Tiny
+		PAR
+		PAR::Repository::Query
 		PAR::Repository::Client
 	} );
 	$self->install_ppm;
 
+	my $cpan_sources = catdir($self->image_dir, 'cpan', 'sources');
+	unless (-d $cpan_sources) {
+		require File::Path;
+		File::Path::mkpath($cpan_sources);
+	}
+	
 	# Console Utilities
 	$self->install_modules( qw{
+		IPC::Run3
+		Test::Script
+		Probe::Perl
+		Number::Compare
+		File::Find::Rule
+		Data::Compare
+		File::chmod
+		Params::Util
+		CPAN::Checksums
+		CPAN::Inject
+		File::pushd
 		pler
 		pip
 	} );
@@ -473,9 +534,50 @@ sub install_perl_modules {
 	$self->install_modules( qw{
 		DBI
 		DBD::SQLite
+		CPAN::DistnameInfo
 		CPAN::SQLite
 	} );
 
+	# Copy the files that CPAN::SQLite needs.
+	# $self->copy_cpan_sqlite_files();
+	
+	# CPANPLUS::Internals::Source::SQLite 
+	# needs this module, so adding it.
+	$self->install_modules( qw{
+		DBIx::Simple
+	} ) if ($self->perl_version eq '5100');
+	
+	# Support for other databases.
+	$self->install_modules( qw{
+		DBD::ODBC
+	} );
+	$self->install_dbd_mysql;
+#	$self->install_dbd_pg;
+
+	my $filelist = $self->install_binary(
+		name       => 'db_libraries',
+		url        => $self->binary_url('DatabaseLibraries-07292009.zip'),
+		install_to => q{.}
+	);
+	$self->insert_fragment( 'db_libraries', $filelist->files );
+
+	# JSON installation
+	$self->install_modules( qw{
+		JSON::XS
+		JSON
+	} );	
+
+	# Local library installation.
+	$self->install_module(    # Fails its test because of a packaging problem in 1.004002 only.
+		name => 'local::lib',
+		force => 1,
+	);
+	
+#	$self->trace_line(0, "Loading extra Strawberry packlists\n");
+
+	# Insert ParserDetails.ini
+	$self->add_to_fragment('XML_SAX', [ catfile($self->image_dir, qw(perl site lib XML SAX ParserDetails.ini)) ]);
+
 	return 1;
 }
 
@@ -489,24 +591,32 @@ sub install_perl_modules {
 sub install_win32_extras {
 	my $self = shift;
 
-	# Link to the Strawberry Perl website.
-	# Don't include this for non-Strawberry sub-classes
-        if ( ref($self) eq 'Perl::Dist::Strawberry' ) {
-		$self->install_file(
-			name       => 'Strawberry Perl Website Icon',
-			url        => 'http://strawberryperl.com/favicon.ico',
-			install_to => 'Strawberry Perl Website.ico',
-		);
-		$self->install_website(
-			name       => 'Strawberry Perl Website',
-			url        => $self->strawberry_url,
-			icon_file  => 'Strawberry Perl Website.ico',
-		);
-	}
-
 	# Add the rest of the extras
 	$self->SUPER::install_win32_extras(@_);
 
+	my $dist_dir = File::ShareDir::dist_dir('Perl-Dist-Strawberry');
+	
+	# Link to the Strawberry Perl website.
+	# Don't include this for non-Strawberry sub-classes
+	if ( ref($self) eq 'Perl::Dist::Strawberry' ) {
+		$self->install_website(
+			name       => 'Strawberry Perl Website',
+			url        => $self->strawberry_url,
+			icon_file  => catfile($dist_dir, 'strawberry.ico')
+		);
+		$self->install_website(
+			name       => 'Live Support',
+			url        => 'http://widget.mibbit.com/?server=irc.perl.org&channel=%23win32',
+			icon_file  => catfile($dist_dir, 'onion.ico')
+		);
+	}
+
+	my $license_file_from = catfile($dist_dir, 'License.rtf');
+	my $license_file_to = catfile($self->license_dir, 'License.rtf');
+	
+	$self->_copy($license_file_from, $license_file_to);
+	$self->add_to_fragment('perl_licenses', [ $license_file_to ]);
+	
 	return 1;
 }
 
@@ -516,7 +626,7 @@ sub strawberry_url {
 
 	# Strip off anything post-version
 	unless ( $path =~ s/^(strawberry-perl-\d+(?:\.\d+)+).*$/$1/ ) {
-		die("Failed to generate the strawberry subpath");
+		die "Failed to generate the strawberry subpath";
 	}
 
 	return "http://strawberryperl.com/$path";
@@ -545,7 +655,7 @@ Returns true or throws an exception on error.
 sub install_patch {
 	my $self = shift;
 
-	$self->install_binary(
+	my $filelist = $self->install_binary(
 		name       => 'patch',
 		url        => $self->binary_url('patch-2.5.9-7-bin.zip'),
 		install_to => {
@@ -559,6 +669,8 @@ sub install_patch {
 		die "Can't execute patch";
 	}
 
+	$self->insert_fragment('patch', $filelist->files);
+
 	return 1;
 }
 
@@ -585,6 +697,14 @@ sub install_ppm {
 		die("PPM build direcotry '$ppmdir' already exists");
 	}
 
+	# Add the ppm directory to the build.
+	$self->directories->add_root_directory(
+		'PPM',       'ppm'
+	);
+
+	# To make sure it's seeable outside of the scope.
+	my $filelist;
+
 	SCOPE: {
 		# The build path in ppm.xml is derived from $ENV{TMP}.
 		# So set TMP to a dedicated location inside of the
@@ -594,11 +714,10 @@ sub install_ppm {
 
 		# Create the ppm temp directory so it exists when
 		# the PPM build needs it.
-		$self->install_file(
+		$filelist = $self->install_file(
 			share      => 'Perl-Dist-Strawberry ppm/README.txt',
 			install_to => 'ppm/README.txt',
 		);
-		$self->add_dir('ppm');
 		unless ( -d $ppmdir ) {
 			die("Failed to create '$ppmdir' directory");
 		}
@@ -610,6 +729,12 @@ sub install_ppm {
 		);
 	}
 
+	# Add the readme file.
+	$self->add_to_fragment('PPM', $filelist->files);
+
+	# Add the ppm.xml file.
+	$self->add_to_fragment('PPM', [ catfile($self->image_dir, qw(perl site lib ppm.xml)) ]);
+
 	return 1;
 }
 
@@ -670,6 +795,108 @@ END_MANIFEST
 	return 1;	
 }
 
+=pod
+
+=head2 install_dbd_mysql
+
+  $dist->install_dbd_mysql;
+
+Installs DBD::mysql from the PAR files on the Strawberry Perl web site.
+
+=cut
+
+sub install_dbd_mysql {
+	my $self = shift;
+	my $filelist;
+
+	if ($self->perl_version eq '5100') {
+		$filelist = $self->install_par(
+		  name => 'DBD_mysql', 
+		  url => 'http://strawberryperl.com/package/DBD-mysql-4.012-MSWin32-x86-multi-thread-5.10.0.par'
+		);
+		$self->insert_fragment( 'DBD_mysql', $filelist->files );
+	} elsif ($self->perl_version eq '589') {
+		$self->trace_line(0, "Installing DBD::mysql is untested in 5.8.9.\n");
+		$filelist = $self->install_par(
+		  name => 'DBD_mysql', 
+		  url => 'http://strawberryperl.com/package/DBD-mysql-4.012-MSWin32-x86-multi-thread-5.8.9.par'
+		);
+		$self->insert_fragment( 'DBD_mysql', $filelist->files );
+	} else {
+		PDWiX->throw('Could not install DBD::mysql - invalid version of perl');
+	}
+}
+
+=pod
+
+=head2 install_dbd_pg
+
+  $dist->install_dbd_pg;
+
+Installs DBD::Pg from the PAR files on the Strawberry Perl web site.
+
+=cut
+
+sub install_dbd_pg {
+	my $self = shift;
+	my $filelist;
+	
+	if ($self->perl_version eq '5100') {
+		$filelist = $self->install_par(
+		  name => 'DBD_Pg', 
+		  url => 'http://strawberryperl.com/package/DBD-Pg-2.13.1-MSWin32-x86-multi-thread-5.10-5.10.0.par'
+		);
+		$self->insert_fragment( 'DBD_Pg', $filelist->files );
+	} elsif ($self->perl_version eq '589') {
+		$self->trace_line(0, "Installing DBD::Pg is untested in 5.8.9.\n");
+		$filelist = $self->install_par(
+		  name => 'DBD_Pg', 
+		  url => 'http://strawberryperl.com/package/DBD-Pg-2.13.1-MSWin32-x86-multi-thread-5.8-5.8.9.par'
+		);
+		$self->insert_fragment( 'DBD_Pg', $filelist->files );
+	} else {
+		PDWiX->throw('Could not install DBD::Pg - invalid version of perl');
+	}
+}
+
+=pod
+
+=head3 install_pari
+
+  $dist->install_pari
+
+The C<install_pari> method install (via a PAR package) libpari and the
+L<Math::Pari> module into the distribution.
+
+This method should only be called at during the install_modules phase.
+
+=cut
+
+sub install_pari {
+	my $self = shift;
+	my $filelist;
+	
+	if ($self->perl_version eq '5100') {
+		$filelist = $self->install_par(
+		  name => 'pari', 
+		  url => 'http://strawberryperl.com/package/Math-Pari-2.010801-MSWin32-x86-multi-thread-5.10.0.par'
+		);
+		$self->insert_fragment( 'pari', $filelist->files );
+	} elsif ($self->perl_version eq '589') {
+		$self->trace_line(0, "Installing DBD::Pg is untested in 5.8.9.\n");
+		$filelist = $self->install_par(
+		  name => 'pari', 
+		  url => 'http://strawberryperl.com/package/Math-Pari-2.010801-MSWin32-x86-multi-thread-5.8.9.par'
+		);
+		$self->insert_fragment( 'pari', $filelist->files );
+	} else {
+		PDWiX->throw('Could not install DBD::Pg - invalid version of perl');
+	}
+
+	return 1;
+} ## end sub install_pari
+
+
 1;
 
 =pod
@@ -691,9 +918,11 @@ Strawberry Perl Support page L<http://strawberryperl.com/support.html>.
 
 Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
+Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
+
 =head1 COPYRIGHT
 
-Copyright 2007 - 2009 Adam Kennedy.
+Copyright 2007 - 2009 Adam Kennedy.  Copyright 2009 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
