@@ -4,16 +4,19 @@ package t::lib::Test;
 
 use strict;
 use File::Spec::Functions ':ALL';
-use Test::More    ();
-use File::Path    ();
-use File::Remove  ();
-use t::lib::Test1 ();
-use t::lib::Test2 ();
-use t::lib::Test3 ();
+use Test::More            ();
+use File::Path            ();
+use File::Remove          ();
+use t::lib::TestNew       ();
+use t::lib::Test5100      ();
+use t::lib::Test588       ();
+use t::lib::Test589       ();
+use t::lib::TestBootstrap ();
+
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.11';
+	$VERSION = '2.00';
 }
 
 
@@ -41,17 +44,27 @@ sub remake_path {
 sub paths {
 	my $class        = shift;
 	my $subpath      = shift || '';
-	my $basedir      = rel2abs( catdir( 't', "tmp$subpath" ) );
-	# File::Remove::clear( $basedir );
-	my $output_dir   = remake_path( catdir( $basedir, 'output'   ) );
-	my $image_dir    = remake_path( catdir( $basedir, 'image'    ) );
-	my $download_dir =   make_path( catdir( $basedir, 'download' ) );
-	my $build_dir    = remake_path( catdir( $basedir, 'build'    ) );
+
+	# Create base and download directory so we can do a GetShortPathName on it.
+	my $basedir  = rel2abs( catdir( 't', "tmp$subpath" ) );
+	my $download = rel2abs( catdir( 't', 'download' ) );
+    File::Path::mkpath( $basedir )  unless -d $basedir;
+	File::Path::mkpath( $download ) unless -d $download;
+	$basedir  = Win32::GetShortPathName( $basedir );
+	$download = Win32::GetShortPathName( $download );
+	Test::More::diag($basedir);
+
+	my $output_dir   = remake_path( catdir( $basedir, 'output'    ) );
+	my $image_dir    = remake_path( catdir( $basedir, 'image'     ) );
+	my $download_dir =   make_path( $download                       );
+	my $fragment_dir = remake_path( catdir( $basedir, 'fragments' ) );
+	my $build_dir    = remake_path( catdir( $basedir, 'build'     ) );
 	return (
 		output_dir   => $output_dir,
 		image_dir    => $image_dir,
 		download_dir => $download_dir,
 		build_dir    => $build_dir,
+		fragment_dir => $fragment_dir,
 	);
 }
 
@@ -67,7 +80,7 @@ sub cpan {
 
 sub new1 {
 	my $class = shift;
-	return t::lib::Test1->new(
+	return t::lib::TestNew->new(
 		cpan => $class->cpan,
 		$class->paths(@_),
 	);
@@ -75,24 +88,38 @@ sub new1 {
 
 sub new2 {
 	my $class = shift;
-	return t::lib::Test2->new(
+	return t::lib::Test5100->new(
 		$class->paths(@_),
 	);
 }
 
 sub new3 {
 	my $class = shift;
-	return t::lib::Test3->new(
+	return t::lib::Test588->new(
 		$class->paths(@_),
 	);
 }
 
 sub new4 {
 	my $class = shift;
-	return t::lib::Test2->new(
+	return t::lib::Test5100->new(
 		$class->paths(@_),
 		portable => 1,
 	);
 }
 
+sub new5 {
+	my $class = shift;
+	return t::lib::Test589->new(
+		$class->paths(@_),
+	);
+}
+
+sub new_bootstrap {
+	my $class = shift;
+	return t::lib::TestBootstrap->new(
+		$class->paths(@_),
+	);
+}
+
 1;
